@@ -10,30 +10,37 @@ from .presolver import presolver as presolver_file
 from .solver import solver as solver_file
 from .centerline import centerline as centerline_file
 
-def build(paths,radii,normals,options):
+def build(paths,radii,normals,options,setup_file=setup_file,
+          path_file=path_file,contour_file=contour_file.split("\n"),
+          geometry_file=geometry_file,loft_file=loft_file,
+          solid_file=solid_file,mesh_file=mesh_file,
+          presolver_file=presolver_file,solver_file=solver_file,
+          centerline_file=centerline_file):
     cco_filename = options.filename
     if options.directory_constructor['create_main_folder']:
         os.mkdir(options.directory_constructor['main_folder'])
     cco_file = open(cco_filename,'w+')
     #setup_file = open(os.path.dirname(__file__)+'/setup.txt','r').read()
     if options.file_constructor['path']:
-        path_file = open(os.path.dirname(__file__)+'/paths.txt','r').read()
+        #path_file = open(os.path.dirname(__file__)+'/paths.txt','r').read()
         path_file = path_file.format(options.file_constructor['gui'])
     else:
         path_file = ''
     if options.file_constructor['contour']:
-        contour_file = open(os.path.dirname(__file__)+'/contour.txt','r').readlines()
+        #contour_file = open(os.path.dirname(__file__)+'/contour.txt','r').readlines()
         contour_file[8] = contour_file[8].format(options.file_constructor['gui'])
+        for i in range(len(contour_file)):
+            contour_file[i] += "\n"
     else:
         contour_file = ''
     if options.file_constructor['solid']:
-        geometry_file = open(os.path.dirname(__file__)+'/geometry.txt','r').read()
+        #geometry_file = open(os.path.dirname(__file__)+'/geometry.txt','r').read()
         geometry_file = geometry_file.format(options.geometry_options['number_samples'],
                                              options.geometry_options['use_distance_alignment_method'])
-        loft_file = open(os.path.dirname(__file__)+'/loft.txt','r').read()
+        #loft_file = open(os.path.dirname(__file__)+'/loft.txt','r').read()
         loft_file = loft_file.format(options.loft_options['changes'],
                                      options.loft_options['angle'])
-        solid_file = open(os.path.dirname(__file__)+'/solid.txt','r').read()
+        #solid_file = open(os.path.dirname(__file__)+'/solid.txt','r').read()
         solid_file = solid_file.format(options.solid_options['minimum_face_cells'],
                                        options.solid_options['hmin'],
                                        options.solid_options['hmax'],
@@ -47,7 +54,7 @@ def build(paths,radii,normals,options):
         loft_file = ''
         solid_file = ''
     if options.file_constructor['mesh']:
-        mesh_file = open(os.path.dirname(__file__)+'/mesh.txt','r').read()
+        #mesh_file = open(os.path.dirname(__file__)+'/mesh.txt','r').read()
         mesh_file = mesh_file.format(options.mesh_options['global_edge_size'],
                                      options.mesh_options['surface_mesh_flag'],
                                      options.mesh_options['volume_mesh_flag'],
@@ -68,12 +75,12 @@ def build(paths,radii,normals,options):
                                      options.directory_constructor['mesh_complete_folder'],
                                      options.directory_constructor['mesh_complete_folder'],
                                      options.directory_constructor['mesh_surfaces_folder'])
-        centerline_file = open(os.path.dirname(__file__)+'/centerline.txt','r').read()
+        #centerline_file = open(os.path.dirname(__file__)+'/centerline.txt','r').read()
         centerline_file = centerline_file.format(options.directory_constructor['centerline_folder'])
     else:
         mesh_files = ''
         centerline_file = ''
-    presolver_file = open(os.path.dirname(__file__)+'/presolver.txt','r').read()
+    #presolver_file = open(os.path.dirname(__file__)+'/presolver.txt','r').read()
     presolver_file = presolver_file.format(options.directory_constructor['data_folder'],
                                            options.presolver_constructor['name'],
                                            options.presolver_constructor['fluid_density'],
@@ -88,7 +95,7 @@ def build(paths,radii,normals,options):
                                            options.presolver_constructor['fourier_mode'],
                                            options.presolver_constructor['inflow_file'],
                                            options.presolver_constructor['pressures'])
-    solver_file = open(os.path.dirname(__file__)+'/solver.txt','r').read()
+    #solver_file = open(os.path.dirname(__file__)+'/solver.txt','r').read()
     solver_file = solver_file.format(options.directory_constructor['data_folder'],
                                      options.solver_constructor['name'],
                                      options.solver_constructor['fluid_density'],
